#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 selective
version:              0.7.0.1
visibility:           public
id:                   selective-0.7.0.1-JQdI4xTNaRVFl2lRFTo1cf
key:                  selective-0.7.0.1-JQdI4xTNaRVFl2lRFTo1cf
license:              MIT
copyright:            Andrey Mokhov, 2018-2024
maintainer:
    Andrey Mokhov <andrey.mokhov@gmail.com>, github: @snowleopard

author:
    Andrey Mokhov <andrey.mokhov@gmail.com>, github: @snowleopard

homepage:             https://github.com/snowleopard/selective
synopsis:             Selective applicative functors
description:
    Selective applicative functors: declare your effects statically,
    select which to execute dynamically.

    This is a library for /selective applicative functors/, or just
    /selective functors/ for short, an abstraction between
    applicative functors and monads, introduced in
    <https://dl.acm.org/doi/10.1145/3341694 this paper>.

category:             Control
abi:                  16abeab04206c26fa8a88f02abf06e34
exposed:              True
exposed-modules:
    Control.Selective Control.Selective.Free Control.Selective.Multi
    Control.Selective.Rigid.Free Control.Selective.Rigid.Freer
    Control.Selective.Trans.Except

import-dirs:          /usr/lib/ghc-9.6.6/site-local/selective-0.7.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/selective-0.7.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/selective-0.7.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-selective
hs-libraries:         HSselective-0.7.0.1-JQdI4xTNaRVFl2lRFTo1cf
depends:              base-4.18.2.1 transformers-0.6.1.0
haddock-interfaces:   /usr/share/doc/haskell-selective/html/selective.haddock
haddock-html:         /usr/share/doc/haskell-selective/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

